@@ -26,13 +26,4 @@ def recipe_run(config, globalconf):
         return result.returncode
 
 
-def depends():
-    """
-    Returns a list of dependencies for this module.
-    Currently this is Debian packages.
-    """
-    return ({'apt': {"priority": "required",
-             "description": "commandline package manager"}})
-
-
 init()
