@@ -20,13 +20,5 @@ def recipe_run(config, globalconf):
                                                     config['mirror']))
 
 
-def depends():
-    """
-    Returns a list of dependencies for this module.
-    Currently this is Debian packages.
-    """
-    # TODO
-    return ({'parted': {"priority": "required", \
-             "description": "disk partition manipulator"} })
 
 init()
