@@ -25,12 +25,4 @@ def recipe_run(config, globalconf):
     create_file(config['size'], config['destination'])
 
 
-def depends():
-    """
-    Returns a list of dependencies for this module.
-    Currently this is Debian packages.
-    """
-    return ({'util-linux': {"priority": "required", \
-             "description": "miscellaneous system utilities"} })
-
 init()
