@@ -20,13 +20,4 @@ def recipe_run(config, globalconf):
         os.system("losetup -P /dev/%s %s" % (config['loopdev'], config['diskimg']))
 
 
-def depends():
-    """
-    Returns a list of dependencies for this module.
-    Currently this is Debian packages.
-    """
-    # TODO
-    return ({'parted': {"priority": "required", \
-             "description": "disk partition manipulator"} })
-
 init()
