@@ -20,12 +20,4 @@ def recipe_run(config, globalconf):
                                                     config['mirror']))
 
 
-def depends():
-    """
-    Returns a list of dependencies for this module.
-    Currently this is Debian packages.
-    """
-    return ({'mmdebstrap': {"priority": "required", \
-             "description": "create a Debian chroot"} })
-
 init()
