@@ -36,13 +36,5 @@ def recipe_run(config, globalconf):
                   filesystem['source'], filesystem['mountpoint']))
 
 
-def depends():
-    """
-    Returns a list of dependencies for this module.
-    Currently this is Debian packages.
-    """
-    # TODO
-    return ({'parted': {"priority": "required", \
-             "description": "disk partition manipulator"} })
 
 init()
