@@ -27,11 +27,4 @@ def recipe_run(config, globalconf):
     readme_w.close()
 
 
-def depends():
-    """
-    Returns a list of dependencies for this module.
-    Currently this is Debian packages.
-    """
-    return ()
-
 init()
