@@ -26,12 +26,4 @@ def recipe_run(config, globalconf):
         # todo
 
 
-def depends():
-    """
-    Returns a list of dependencies for this module.
-    Currently this is Debian packages.
-    """
-    return ({'squashfs-tools-ng': {"priority": "required", \
-             "description": "set of tools for working with squashfs images"} })
-
 init()
