@@ -25,12 +25,4 @@ def recipe_run(config, globalconf):
             os.system("chroot /tmp/disk apt-get install sudo")
 
 
-def depends():
-    """
-    Returns a list of dependencies for this module.
-    Currently this is Debian packages.
-    """
-    return ({'apt': {"priority": "required", \
-             "description": "commandline package manager"} })
-
 init()
