@@ -28,12 +28,4 @@ def recipe_run(config, globalconf):
     os.system("chroot %s /usr/sbin/update-grub" % chroot)
 
 
-def depends():
-    """
-    Returns a list of dependencies for this module.
-    Currently this is Debian packages.
-    """
-    return ({'vmsetup': {"priority": "required", \
-             "description": "disk partition manipulator"} })
-
 init()
