@@ -34,12 +34,4 @@ def write_file(file, content):
     file.close()
 
 
-def depends():
-    """
-    Returns a list of dependencies for this module.
-    Currently this is Debian packages.
-    """
-    return ({'curl': {"priority": "required", \
-             "description": "command line tool for transferring data with URL syntax"} })
-
 init()
